@@ -25,17 +25,19 @@ class Publish:
 
     def run(self, stdin, log):
         try:
-            sh.poetry("run", "pytest")
+            print(sh.poetry("run", "pytest"))
         except sh.ErrorReturnCode_5:
             pass
         print(sh.poetry("version", self.rule))
         print(sh.poetry("build"))
-        sh.poetry("publish")
-        sh.git("commit", "-a", "-m", "Bump version in pyproject.toml")
-        sh.git("push")
-        sh.gh("release", "create", sh.poetry("version", "-s"),
-              sh.tail(sh.grep(sh.ls("-tr", "dist"), ".whl"), "-n1"))
-        sh.git("pull")
+        print(sh.poetry("publish"))
+        print(sh.git("commit", "-a", "-m", "Bump version in pyproject.toml"))
+        print(sh.git("push"))
+        version = sh.poetry("version", "-s")
+        asset = sh.tail(sh.grep(sh.ls("-tr", "dist"), ".whl"), "-n1")
+        print(sh.gh("release", "create", version, f"dist/{asset}"))
+        print(sh.git("pull"))
+        print("Published v{version}!")
         return 0
 
 
